![Pip](https://github.com/pthom/litgen/workflows/ci_build_and_test/badge.svg)


litgen, also known as Literate Generator, is an automatic python bindings generator for humans who like nice code and APIs.

It can be used to bind C++ libraries into documented and discoverable python modules using pybind11.

It can also be used as C++ transformation/refactoring tool.

[See documentation](https://pthom.github.io/litgen/)
